package com.puppycrawl.tools.checkstyle.checks.design.visibilitymodifier;

import com.puppycrawl.tools.checkstyle.*;

public class InputVisibilityModifierIsStarImport {
}
